#!/bin/sh

# 日志函数
log_info() {
    logger -t navigator -p info "$1"
}

log_error() {
    logger -t navigator -p err "$1"
}

# 获取配置
PORT=$(uci -q get navigator.basic.port)
UPDATE_INTERVAL=$(uci -q get navigator.advanced.update_interval)

# 检查配置
[ -z "$PORT" ] && {
    log_error "Port not configured"
    exit 1
}

[ -z "$UPDATE_INTERVAL" ] && UPDATE_INTERVAL=5

# 检查端口是否存在
[ -e "/dev/$PORT" ] || {
    log_error "Port /dev/$PORT does not exist"
    exit 1
}

# 检查gpsd是否运行
if ! pgrep gpsd >/dev/null; then
    log_error "gpsd is not running"
    exit 1
fi

# 获取GPS数据
get_gps_data() {
    # 使用timeout确保命令不会永久挂起
    timeout 5 gpspipe -w -n 5 | while read -r line; do
        # 检查是否为TPV数据
        if echo "$line" | grep -q '"class":"TPV"'; then
            # 提取经纬度和模式
            local lat=$(echo "$line" | jsonfilter -e '@.lat')
            local lon=$(echo "$line" | jsonfilter -e '@.lon')
            local mode=$(echo "$line" | jsonfilter -e '@.mode')
            
            # 检查数据有效性
            if [ -n "$lat" ] && [ -n "$lon" ] && [ "$mode" -gt 1 ]; then
                echo "$lat,$lon"
                return 0
            fi
        fi
    done
    return 1
}

# 尝试获取GPS数据
gps_data=$(get_gps_data)
if [ $? -eq 0 ]; then
    log_info "GPS data obtained successfully: $gps_data"
    echo "$gps_data"
    exit 0
else
    log_error "Failed to get valid GPS data"
    exit 1
fi
