#!/bin/sh

# 导航服务主脚本
# 功能：GPS位置获取、地图服务接口

. /lib/functions.sh
. /lib/functions/network.sh

# 配置文件路径
CONFIG_FILE="/etc/config/navigator"
GPS_DATA="/tmp/gps_location"
LOCK_FILE="/var/run/navigator.lock"

# 获取配置
get_config() {
    local section="$1"
    local option="$2"
    local default="$3"
    local value
    
    config_load navigator
    config_get value "$section" "$option" "$default"
    echo "$value"
}

# 初始化GPS设备
init_gps() {
    local device
    local baudrate
    
    device=$(get_config "gps" "device" "/dev/ttyUSB0")
    baudrate=$(get_config "gps" "baudrate" "9600")
    
    # 配置串口
    stty -F "$device" "$baudrate"
    
    # 启动gpsd服务
    if [ -x /usr/sbin/gpsd ]; then
        killall gpsd 2>/dev/null
        gpsd -n "$device"
    fi
}

# 获取GPS位置
get_gps_location() {
    local data
    
    if [ -x /usr/bin/gpspipe ]; then
        data=$(gpspipe -w -n 5 | grep -m 1 TPV)
        if [ -n "$data" ]; then
            echo "$data" > "$GPS_DATA"
        fi
    fi
}

# 主循环
main_loop() {
    local interval
    
    interval=$(get_config "gps" "update_interval" "5")
    
    while true; do
        if [ -f "$LOCK_FILE" ]; then
            get_gps_location
            sleep "$interval"
        else
            break
        fi
    done
}

# 启动服务
start_service() {
    if [ ! -f "$LOCK_FILE" ]; then
        touch "$LOCK_FILE"
        init_gps
        main_loop &
    fi
}

# 停止服务
stop_service() {
    if [ -f "$LOCK_FILE" ]; then
        rm -f "$LOCK_FILE"
        killall gpsd 2>/dev/null
    fi
}

case "$1" in
    start)
        start_service
        ;;
    stop)
        stop_service
        ;;
    restart)
        stop_service
        start_service
        ;;
    *)
        echo "Usage: $0 {start|stop|restart}"
        exit 1
        ;;
esac

exit 0