#!/bin/sh

# 日志函数
log_info() {
    logger -t navigator -p info "$1"
}

log_error() {
    logger -t navigator -p err "$1"
}

# 检查sms-tool是否存在
if ! which sms_tool >/dev/null 2>&1; then
    log_error "sms-tool not found. Please install sms-tool package."
    exit 1
fi

# 获取配置
PORT=$(uci -q get navigator.basic.port)
MODEM_TYPE=$(uci -q get navigator.basic.modem_type)
GNSS_MODE=$(uci -q get navigator.basic.gnss_mode || echo "gps")

# 检查配置是否存在
[ -z "$PORT" ] && {
    log_error "Port not configured"
    exit 1
}

# 检查端口是否存在
[ -e "/dev/$PORT" ] || {
    log_error "Port /dev/$PORT does not exist"
    exit 1
}

# 设置端口权限
chmod 666 "/dev/$PORT"

# 根据模块类型初始化GNSS
DEVICE="/dev/$PORT"

init_gnss() {
    local result=1
    case "$MODEM_TYPE" in
        "neoway")
            # 根据GNSS模式设置
            case "$GNSS_MODE" in
                "gps")
                    sms_tool -d "$DEVICE" at "AT\$MYNSSMODE=0" && \
                    sms_tool -d "$DEVICE" at "AT\$MYGPSPWR=1" && result=0
                    ;;
                "gps_bds")
                    sms_tool -d "$DEVICE" at "AT\$MYNSSMODE=1" && \
                    sms_tool -d "$DEVICE" at "AT\$MYGPSPWR=1" && result=0
                    ;;
                "gps_glonass")
                    sms_tool -d "$DEVICE" at "AT\$MYNSSMODE=2" && \
                    sms_tool -d "$DEVICE" at "AT\$MYGPSPWR=1" && result=0
                    ;;
                "gps_bds_glonass")
                    sms_tool -d "$DEVICE" at "AT\$MYNSSMODE=3" && \
                    sms_tool -d "$DEVICE" at "AT\$MYGPSPWR=1" && result=0
                    ;;
            esac
            ;;
        "quectel")
            # 根据GNSS模式设置
            case "$GNSS_MODE" in
                "gps")
                    sms_tool -d "$DEVICE" at "AT+QGPSCFG=\"gnssconfig\",1" && \
                    sms_tool -d "$DEVICE" at "AT+QGPS=1" && result=0
                    ;;
                "gps_glonass")
                    sms_tool -d "$DEVICE" at "AT+QGPSCFG=\"gnssconfig\",2" && \
                    sms_tool -d "$DEVICE" at "AT+QGPS=1" && result=0
                    ;;
                "gps_galileo")
                    sms_tool -d "$DEVICE" at "AT+QGPSCFG=\"gnssconfig\",3" && \
                    sms_tool -d "$DEVICE" at "AT+QGPS=1" && result=0
                    ;;
                "gps_bds")
                    sms_tool -d "$DEVICE" at "AT+QGPSCFG=\"gnssconfig\",4" && \
                    sms_tool -d "$DEVICE" at "AT+QGPS=1" && result=0
                    ;;
            esac
            ;;
        "huawei")
            # 根据GNSS模式设置
            case "$GNSS_MODE" in
                "gps")
                    sms_tool -d "$DEVICE" at "AT^GPSTYPE=0" && \
                    sms_tool -d "$DEVICE" at "AT^GPS=1" && result=0
                    ;;
                "gps_glonass")
                    sms_tool -d "$DEVICE" at "AT^GPSTYPE=1" && \
                    sms_tool -d "$DEVICE" at "AT^GPS=1" && result=0
                    ;;
                "gps_galileo")
                    sms_tool -d "$DEVICE" at "AT^GPSTYPE=2" && \
                    sms_tool -d "$DEVICE" at "AT^GPS=1" && result=0
                    ;;
                "gps_bds")
                    sms_tool -d "$DEVICE" at "AT^GPSTYPE=3" && \
                    sms_tool -d "$DEVICE" at "AT^GPS=1" && result=0
                    ;;
            esac
            ;;
        "zte")
            sms_tool -d "$DEVICE" at "AT+ZGPS=1" && result=0
            ;;
        "fibocom")
            sms_tool -d "$DEVICE" at "AT+GTGPS=1" && result=0
            ;;
        *)
            log_error "Unsupported modem type: $MODEM_TYPE"
            return 1
            ;;
    esac

    if [ $result -eq 0 ]; then
        log_info "GNSS initialized successfully for $MODEM_TYPE modem with mode $GNSS_MODE"
    else
        log_error "Failed to initialize GNSS for $MODEM_TYPE modem"
    fi
    return $result
}

# 尝试初始化GNSS
init_gnss || exit 1

exit 0
