#!/bin/sh

# 天气和路况服务脚本
# 功能：获取天气信息和路况数据

. /lib/functions.sh
. /lib/functions/network.sh

# 配置和缓存文件
CONFIG_FILE="/etc/config/navigator"
WEATHER_CACHE="/tmp/weather_data"
TRAFFIC_CACHE="/tmp/traffic_data"

# 获取配置
get_config() {
    local section="$1"
    local option="$2"
    local default="$3"
    local value
    
    config_load navigator
    config_get value "$section" "$option" "$default"
    echo "$value"
}

# 获取当前位置
get_current_location() {
    local data
    local lat
    local lon
    
    if [ -f "/tmp/gps_location" ]; then
        data=$(cat "/tmp/gps_location")
        lat=$(echo "$data" | jsonfilter -e '@.lat')
        lon=$(echo "$data" | jsonfilter -e '@.lon')
        echo "$lat,$lon"
    fi
}

# 获取天气数据
get_weather() {
    local api_key
    local location
    local url
    local response
    
    api_key=$(get_config "weather" "api_key")
    [ -z "$api_key" ] && return 1
    
    location=$(get_current_location)
    [ -z "$location" ] && return 1
    
    url="http://api.openweathermap.org/data/2.5/weather?lat=${location%,*}&lon=${location#*,}&appid=${api_key}&units=metric"
    
    response=$(curl -s "$url")
    if [ $? -eq 0 ]; then
        echo "$response" > "$WEATHER_CACHE"
    fi
}

# 获取路况数据
get_traffic() {
    local api_key
    local location
    local url
    local response
    
    api_key=$(get_config "traffic" "api_key")
    [ -z "$api_key" ] && return 1
    
    location=$(get_current_location)
    [ -z "$location" ] && return 1
    
    url="https://traffic.ls.hereapi.com/traffic/6.2/flow.json?apiKey=${api_key}&bbox=${location%,*},${location#*,}"
    
    response=$(curl -s "$url")
    if [ $? -eq 0 ]; then
        echo "$response" > "$TRAFFIC_CACHE"
    fi
}

# 主循环
main_loop() {
    local weather_interval
    local traffic_interval
    
    weather_interval=$(get_config "weather" "update_interval" "3600")
    traffic_interval=$(get_config "traffic" "update_interval" "300")
    
    while true; do
        if [ "$(get_config "weather" "enabled" "1")" = "1" ]; then
            get_weather
            sleep "$weather_interval"
        fi
        
        if [ "$(get_config "traffic" "enabled" "1")" = "1" ]; then
            get_traffic
            sleep "$traffic_interval"
        fi
    done
}

case "$1" in
    start)
        main_loop &
        ;;
    stop)
        killall weather_traffic.sh 2>/dev/null
        ;;
    *)
        echo "Usage: $0 {start|stop}"
        exit 1
        ;;
esac

exit 0